@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.50 2002/10/01 04:13:18 bkorb Exp $
+ *  $Id: autoopts.c,v 3.24 2003/04/21 03:35:35 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,8 +51,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
-
 #ifndef HAVE_PATHFIND
 #  include "compat/pathfind.c"
 #endif
@@ -65,8 +63,6 @@ tSCC zIllOptChr[]   = "%s: illegal option -- %c\n";
 tSCC zIllegal[]     = "illegal";
 tSCC zIllOptStr[]   = "%s: %s option -- %s\n";
 tSCC zAmbiguous[]   = "ambiguous";
-tSCC zOptArg[]      = "option argument";
-
 
 tSCC zOnlyOne[]     = "one %s%s option allowed\n";
 tSCC zAtMost[]      = "%4$d %1$s%s options allowed\n";
@@ -660,7 +656,7 @@ optionMakePath( pzBuf, bufSize, pzName, pzProgPath )
     }
 
     /*
-     *  IF the name starts with "$$", then it must start be "$$" or
+     *  IF the name starts with "$$", then it must be "$$" or
      *  it must start with "$$/".  In either event, replace the "$$"
      *  with the path to the executable and append a "/" character.
      */
@@ -668,6 +664,19 @@ optionMakePath( pzBuf, bufSize, pzName, pzProgPath )
         tCC*  pzPath;
         tCC*  pz;
 
+        switch (pzName[2]) {
+        case '/':
+        case NUL:
+            break;
+        default:
+            return AG_FALSE;
+        }
+
+        /*
+         *  See if the path is included in the program name.
+         *  If it is, we're done.  Otherwise, we have to hunt
+         *  for the program using "pathfind".
+         */
         if (strchr( pzProgPath, '/' ) != (char*)NULL)
             pzPath = pzProgPath;
         else {
@@ -987,13 +996,13 @@ loadOptionLine( pOpts, pOS, pzLine, direction )
     case ARG_MAY:
         if (*pOS->pzOptArg == NUL)
              pOS->pzOptArg = NULL;
-        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, zOptArg );
+        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, "option argument" );
         break;
 
     case ARG_MUST:
         if (*pOS->pzOptArg == NUL)
              pOS->pzOptArg = "";
-        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, zOptArg );
+        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, "option argument" );
         break;
     }
 
@@ -1016,7 +1025,6 @@ filePreset( pOpts, pzFileName, direction )
     teSec   sec     = SEC_NONE;
     FILE*   fp      = fopen( pzFileName, (const char*)"r" FOPEN_BINARY_FLAG );
     u_int   saveOpt = pOpts->fOptSet;
-    size_t  secNameLen;
     char    zLine[ 0x1000 ];
 
     if (fp == (FILE*)NULL)
@@ -1081,15 +1089,17 @@ filePreset( pOpts, pzFileName, direction )
             switch (sec) {
             case SEC_NONE:
                 sec = SEC_LOOKING;
-                secNameLen = strlen( pOpts->pzPROGNAME );
                 /* FALLTHROUGH */
 
             case SEC_LOOKING:
+            {
+                int secNameLen = strlen( pOpts->pzPROGNAME );
                 if (  (strncmp( pzLine+1, pOpts->pzPROGNAME, secNameLen ) != 0)
                    || (pzLine[secNameLen+1] != ']')  )
                     continue;
                 sec = SEC_PROCESS;
                 break;
+            }
 
             case SEC_PROCESS:
                 goto fileDone;
@@ -1225,7 +1235,7 @@ doEnvPresets( pOpts, type )
             case ARG_MUST:
                 if (*st.pzOptArg == NUL)
                      st.pzOptArg = "";
-                else AGDUPSTR( st.pzOptArg, st.pzOptArg, zOptArg );
+                else AGDUPSTR( st.pzOptArg, st.pzOptArg, "option argument" );
                 break;
 
             default: /* no argument allowed */
@@ -1518,7 +1528,8 @@ void optionLoadLine( pOpts, pzLine )
     tCC*       pzLine;
 {
     tOptState st = { NULL, OPTST_SET, TOPT_UNDEFINED, 0, NULL };
-    char* pz = AGDUPSTR( pzLine, pzLine, "user option line" );
+    char* pz;
+    AGDUPSTR( pz, pzLine, "user option line" );
     loadOptionLine( pOpts, &st, pz, DIRECTION_PROCESS );
     AGFREE( pz );
 }
@@ -1738,8 +1749,10 @@ optionProcess( pOpts, argCt, argVect )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * tab-width: 4
  * End:
- * autoopts.c ends here */
+ * end of autoopts/autoopts.c */
