@@ -1,6 +1,6 @@
 
 /*
- *  save.c  $Id: save.c,v 2.20 2003/02/15 22:58:59 bkorb Exp $
+ *  save.c  $Id: save.c,v 3.12 2003/04/21 03:35:35 bkorb Exp $
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
@@ -50,9 +50,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
-#include <time.h>
-
 tSCC  zWarn[] = "%s WARNING:  cannot save options - ";
 
 STATIC char*
@@ -265,7 +262,7 @@ printEntry( fp, p, pzLA )
      *  THEN the char pointer is really the number
      */
     if ((p->fOptState & OPTST_NUMERIC) != 0)
-        fprintf( fp, "  %ld\n", (t_word)pzLA );
+        fprintf( fp, "  %d\n", (t_word)pzLA );
 
     /*
      *  OTHERWISE, FOR each line of the value text, ...
@@ -438,7 +435,7 @@ optionSaveFile( pOpts )
 
             case OPTST_ENUMERATION:
             {
-                int enumVal = (int)(p->pzLastArg);
+                uintptr_t enumVal = (uintptr_t)(p->pzLastArg);
                 /*
                  *  This is a magic incantation that will convert the
                  *  enumeration value back into a string suitable for printing.
@@ -464,7 +461,9 @@ optionSaveFile( pOpts )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * save.c ends here */
+ * end of autoopts/save.c */
