@@ -1,6 +1,6 @@
 
 /*
- *  $Id: streqvcmp.c,v 2.18 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: streqvcmp.c,v 3.8 2003/04/29 01:51:05 bkorb Exp $
  *
  *  String Equivalence Comparison
  *
@@ -53,8 +53,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
-
 /*
  * This array is designed for mapping upper and lower case letter
  * together for a case independent comparison.  The mappings are
@@ -141,16 +139,8 @@ streqvcmp( s1, s2 )
 }
 
 
-#ifdef __STDC__
 void
 streqvmap( char From, char To, int ct )
-#else
-void
-streqvmap( From, To, ct )
-    char From;
-    char To;
-    int  ct;
-#endif
 {
     if (ct == 0) {
         ct = sizeof( charmap ) - 1;
@@ -162,7 +152,6 @@ streqvmap( From, To, ct )
     else {
         int  chTo   = (int)To   & 0xFF;
         int  chFrom = (int)From & 0xFF;
-        int  delta  = chTo - chFrom;
 
         do  {
             charmap[ chFrom ] = (unsigned)chTo;
@@ -197,9 +186,12 @@ strtransform( d, s )
     } while (*(s++) != NUL);
 }
 
+
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * streqvcmp.c ends here */
+ * end of autoopts/streqvcmp.c */
