@@ -1,5 +1,5 @@
 
-/*  $Id: version.c,v 2.13 2003/02/15 22:58:59 bkorb Exp $
+/*  $Id: version.c,v 3.7 2003/04/21 03:35:35 bkorb Exp $
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
@@ -48,8 +48,6 @@ static const char zAOV[] =
  * If you do not wish that, delete this exception notice.
  */
 
-#include "autoopts.h"
-
 tSCC zBadArg[] =
 "ERROR: version option argument '%c' invalid.  Use:\n\
 \t'v' - version only\n\
@@ -136,7 +134,9 @@ doVersionStderr( pOpts, pOD )
 
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * version.c ends here */
+ * end of autoopts/version.c */
