@@ -147,6 +147,10 @@ void free ();
    extern char *strchr(), *strrchr();
 #endif
 
+#ifndef NUL
+#  define NUL '\0'
+#endif
+
 /* Prototypes for functions defined here.  */
 
 VOID *xmalloc __P((size_t n));
